run_cli_with_custom_connection

Function run_cli_with_custom_connection 

pub async fn run_cli_with_custom_connection(
    migrator: impl MigratorTraitSelf,
    make_connection: impl AsyncFnOnce() -> Result<DbConn, DbErr>,
)
Same as run_cli where you provide a fully customized way to create the DbConn.

This allows loading database configuration from sources other than CLI arguments or environment variables.